@page {
  @top-left {
    content: counter(page);
    height: 1cm;
    text-align: center;
    width: 1cm;
    background: url("/home/xin/dossiercompetence/exemple/pied.png");
  }
  
  @bottom-center {
    content: counter(page);
    height: 1cm;
    text-align: center;
    width: 1cm;
  }
}



body {
    font-family: 'Gill Sans', 'Gill Sans MT', Calibri, 'Trebuchet MS', sans-serif;
    font-size: 10px;
  }

  /* NOM et prénom */
  h1 {
    color: black;
    font-size: 12px;
    font-weight: bold;
    font-family:'Gill Sans', 'Gill Sans MT', Calibri, 'Trebuchet MS', sans-serif;
  }

  /* Post */
  h2 {
    color: black;
    font-size: 12px;
    font-weight: bold;
    font-family:'Gill Sans', 'Gill Sans MT', Calibri, 'Trebuchet MS', sans-serif;
  }
  
  /* Title de la chaque parties */
  h3 {
    color:  #009C9D;
    font-size: 14px;
    font-family:'Gill Sans', 'Gill Sans MT', Calibri, 'Trebuchet MS', sans-serif;
  }

  /* délimiteur */
  h5 {
    color: #009C9D;
    font-size: 12px;
    font-weight: bold;
    text-align: center;
  }

  h4 {
    color:  #009C9D;
    font-size: 12px;
    font-family:'Gill Sans', 'Gill Sans MT', Calibri, 'Trebuchet MS', sans-serif;
  }

  li {
    line-height: 18px;
    list-style-type: disc;
  }
  
  p {
    color: black;
    line-height: 1.5;
  }

  em {
    color:  #009C9D;
    font-size: 12px;
    font-family:'Gill Sans', 'Gill Sans MT', Calibri, 'Trebuchet MS', sans-serif;
  }
